
body {
    font-family: "Arial";
}

table {
    width: 100%;
    font-size: 12px;
}

thead {
    background: #dddddd;
}

thead th {
    text-align: center;
}

.action,
.host-spec,
.user-spec,
.threads-spec,
.checkbox-spec,
.load-spec,
.started-spec,
.tempstorage-spec,
.vmdatasize-spec,
.date-spec {
    text-align: center;
}

.overlay { 
     
    /* must be initially hidden */ 
    display:none; 
     
    /* place overlay on top of other elements */ 
    z-index:10000; 
     
    /* styling */ 
    background-color:#dddddd; 
     
    width:800px;     
    min-height:200px; 
    border:1px solid #666; 
    padding: 1em;
     
    /* CSS3 styling for latest browsers */ 
    -moz-box-shadow:0 0 90px 5px #000; 
    -webkit-box-shadow: 0 0 90px #000;     
    text-align: left;
} 
 
/* close button positioned on upper right corner */ 
.overlay .close { 
    background-image:url(/++resource++haufe.monitoring/close.png); 
    position:absolute; 
    right:-15px; 
    top:-15px; 
    cursor:pointer; 
    height:35px; 
    width:35px; 
}

.warning {
        color: red;
        padding-bottom: 1em;
}

.error {
    color: red;
    font-weight: bold;
}

